@@ -1,5 +1,5 @@
 /*
- * $Id: about.h,v 1.3 1998/04/17 20:06:29 gregm Exp $
+ * $Id: about.h,v 1.4 1998/09/27 01:30:44 gregm Exp $
  * GXSNMP -- An snmp mangament application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -21,7 +21,7 @@
  */
 #ifndef __ABOUT_H__
 #define __ABOUT_H__
-#include <gtk/gtk.h>
+#include <gnome.h>
 
 /*
  * Global function declarations 
