@@ -1,5 +1,5 @@
 /*
- * $Id: browser.c,v 1.19 1998/08/10 23:09:41 gregm Exp $
+ * $Id: browser.c,v 1.26 1998/09/22 22:35:35 gregm Exp $
  * GXSNMP - An snmp managment application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -19,12 +19,10 @@
  *
  * The mib browser panel.
  */
-#ifndef lint
-static char const copyright[] = 
-"@(#) Copyright (C) 1998 Gregory McLean";
-#endif
-
+#include <config.h>
 #include "main.h"
+#include "structs.h"
+#include "protos.h"
 
 static void       create_browser_panel          (void);
 static void       build_mib_tree                (void);
@@ -307,88 +305,71 @@ create_browser_panel ()
   hosts        *host;
 
   app_info->brows_panel = (browser_panel *)g_malloc (sizeof (browser_panel));
-  app_info->brows_panel->window = new_window (_("GXSNMP: Mib Browser"),
-					      GTK_WINDOW_TOPLEVEL,
-					      GTK_WIN_POS_NONE, 2);
+  app_info->brows_panel->window = gnome_app_new ("GXSNMP", _("Mib Browser"));
   gtk_signal_connect (GTK_OBJECT (app_info->brows_panel->window),
 		      "delete_event",
 		      GTK_SIGNAL_FUNC (panel_delete_cb),
 		      NULL);
-  host = get_current_host ();
+  host = get_current_host (app_info->brows_panel);
   vbox = gtk_vbox_new (FALSE, 4);
-  gtk_container_add (GTK_CONTAINER (app_info->brows_panel->window), vbox);
-  gtk_widget_show (vbox);
+  gnome_app_set_contents (GNOME_APP (app_info->brows_panel->window), vbox);
+
   frame = gtk_frame_new (NULL);
   gtk_container_border_width (GTK_CONTAINER (frame), 2);
   gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 1);
-  gtk_widget_show (frame);
   vbox = gtk_vbox_new (FALSE, 2);
   gtk_container_border_width (GTK_CONTAINER (vbox), 4);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
-  gtk_widget_show (vbox);
   hbox = gtk_hbox_new (FALSE, 2);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
-  gtk_widget_show (hbox);
   left_box = gtk_vbox_new (FALSE, 2);
   gtk_box_pack_start (GTK_BOX (hbox), left_box, TRUE, TRUE, 0);
-  gtk_widget_show (left_box);
   right_box = gtk_vbox_new (FALSE, 2);
   gtk_box_pack_start (GTK_BOX (hbox), right_box, FALSE, FALSE, 2);
-  gtk_widget_show (right_box);
 
   frame = gtk_frame_new (NULL);
   gtk_box_pack_start (GTK_BOX (right_box), frame, FALSE, FALSE, 0);
-  gtk_widget_show (frame);
   table = gtk_table_new ( 5, 2, FALSE);
   gtk_container_add (GTK_CONTAINER (frame), table);
   label = gtk_label_new (_("Object Type"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 2);
-  gtk_widget_show (label);
   app_info->brows_panel->mib_type = gtk_entry_new ();
   gtk_entry_set_editable (GTK_ENTRY (app_info->brows_panel->mib_type), FALSE);
   gtk_table_attach (GTK_TABLE (table), app_info->brows_panel->mib_type,
 		    1, 2, 0, 1,
 		    GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 2);
-  gtk_widget_show (app_info->brows_panel->mib_type);
   label = gtk_label_new (_("OID"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 2);
-  gtk_widget_show (label);
   app_info->brows_panel->mib_oid = gtk_entry_new ();
   gtk_entry_set_editable (GTK_ENTRY (app_info->brows_panel->mib_oid), FALSE);
   gtk_table_attach (GTK_TABLE (table), app_info->brows_panel->mib_oid, 
 		    1, 2, 1, 2,
 		    GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 2);
-  gtk_widget_show (app_info->brows_panel->mib_oid);
   label = gtk_label_new (_("Label"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 2);
-  gtk_widget_show (label);
   app_info->brows_panel->mib_label = gtk_entry_new ();
   gtk_entry_set_editable (GTK_ENTRY (app_info->brows_panel->mib_label), FALSE);
   gtk_table_attach (GTK_TABLE (table), app_info->brows_panel->mib_label,
 		    1, 2, 2, 3, 
 		    GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 2);
-  gtk_widget_show (app_info->brows_panel->mib_label);
   label = gtk_label_new (_("Value"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 2);
-  gtk_widget_show (label);
   app_info->brows_panel->mib_value = gtk_entry_new ();
   gtk_table_attach (GTK_TABLE (table), app_info->brows_panel->mib_value,
 		    1, 2, 3, 4,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 2);
-  gtk_widget_show (app_info->brows_panel->mib_value);
   label = gtk_label_new (_("Host"));
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 4, 5,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK, 2, 2);
-  gtk_widget_show (label);
   app_info->brows_panel->mib_host = gtk_combo_new ();
   if (app_info->host_hash == NULL)
     {
@@ -398,9 +379,10 @@ create_browser_panel ()
     }
   else
     {
-      gtk_entry_set_text (GTK_ENTRY (GTK_COMBO
-				     (app_info->brows_panel->mib_host)->entry),
-			  host->hl_snmp.name);
+      if (host)
+	gtk_entry_set_text (GTK_ENTRY (GTK_COMBO
+			    (app_info->brows_panel->mib_host)->entry),
+			    host->hl_snmp.name);
     }
   gtk_table_attach (GTK_TABLE (table), app_info->brows_panel->mib_host,
 		    1, 2, 4, 5,
@@ -539,8 +521,7 @@ create_browser_panel ()
 				FALSE);
   gtk_container_add (GTK_CONTAINER (button_box),
 		     app_info->brows_panel->rbutton);
-  gtk_widget_show (app_info->brows_panel->rbutton);
-  gtk_widget_show (app_info->brows_panel->window);
+  gtk_widget_show_all (app_info->brows_panel->window);
 }
 
 static void
@@ -637,7 +618,6 @@ put_button_cb (GtkWidget *widget, gpointer data)
   GList        *sel;
   GtkTreeItem  *sel_item;
   struct tree  *snmptree;
-  char         oidbuf[1024];
   char         *value;
   guint32      val;
   GSList       *objs;
@@ -704,7 +684,7 @@ refresh_mib_tree (hosts *host)
 /*
  * snmp callback
  */
-void
+gboolean
 update_mib_value (host_snmp *host, void *magic, SNMP_PDU *spdu, GSList *objs)
 {
   char    buf[1024];
@@ -743,7 +723,7 @@ update_mib_value (host_snmp *host, void *magic, SNMP_PDU *spdu, GSList *objs)
 	       host->name);
       update_app_stat (buf);
     }
-  return;
+  return TRUE;
 }
 
 /*
@@ -786,7 +766,7 @@ open_browser_panel ()
 {
   hosts   *host;
 
-  host = get_current_host ();
+  host = get_current_host (NULL);
   if(app_info->brows_panel == NULL)
     {
       create_browser_panel ();
