@@ -1,5 +1,5 @@
 /*
- * $Id: config_panel.c,v 1.21 1998/07/04 15:58:38 gregm Exp $
+ * $Id: config_panel.c,v 1.25 1998/09/27 01:30:49 gregm Exp $
  * GXSNMP -- An snmp management application.
  * Copyright (C) 1998 Gregory Mclean
  *
@@ -19,15 +19,6 @@
  *
  * The configuration panel 
  */
-#ifndef lint
-static char const copyright[] =
-"@(#) Copyright (c) 1998 Gregory McLean";
-#endif
-static char const rcsid[] = 
- "$Id: config_panel.c,v 1.21 1998/07/04 15:58:38 gregm Exp $";
-
-#include <string.h>
-#include <gtk/gtk.h>
 #include "main.h"
 #include "gui.h"
 
@@ -101,6 +92,13 @@ static gint             panel_delete_cb           (GtkWidget       *widget,
 						   gpointer        data);
 static void             color_changed_cb          (GnomeColorSelector *widget,
 						   gchar              **color);
+static GTCallbacks config_buttons[] = {
+  { GT_BUTTON_OK, ok_button_cb, NULL, "ok_button" },
+  { GT_BUTTON_CAN, cancel_button_cb, NULL, "cancel_button" },
+  { GT_BUTTON_DEFAULT, NULL, NULL, "default_button" },
+  { GT_BUTTON_SAVE, save_button_cb, NULL, "save_button" },
+  { GT_UI_END, NULL, NULL, NULL }
+};
 
 /*
  * global functions
@@ -121,7 +119,6 @@ create_config_panel ()
   GnomeColorSelector  *colorsel;
   GtkWidget           *colbutton;
   gchar               *dummy;
-  GtkMenuFactory *mf;
   char           buf[20];
   int            i;
 
@@ -373,34 +370,13 @@ create_config_panel ()
   gtk_widget_show (bar);
 
   button_box = gtk_hbutton_box_new ();
-  gtk_container_border_width (GTK_CONTAINER (button_box), 4);
+  gtk_container_border_width (GTK_CONTAINER (button_box), 10);
   gtk_button_box_set_layout (GTK_BUTTON_BOX (button_box),
                              GTK_BUTTONBOX_SPREAD);
   gtk_button_box_set_spacing (GTK_BUTTON_BOX (button_box), 2);
   gtk_button_box_set_child_size (GTK_BUTTON_BOX (button_box), 85, 20);
   gtk_box_pack_start (GTK_BOX (vbox), button_box, FALSE, FALSE, 0);
-
-
-  button = gnome_stock_button (GNOME_STOCK_BUTTON_OK);
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-                      GTK_SIGNAL_FUNC (ok_button_cb),
-                      NULL);
-  gtk_container_add (GTK_CONTAINER (button_box), button);
-
-  button = gnome_stock_button (GNOME_STOCK_BUTTON_CANCEL);
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-                      GTK_SIGNAL_FUNC (cancel_button_cb),
-                      NULL);
-  gtk_container_add (GTK_CONTAINER (button_box), button);
-
-  button = gtk_button_new_with_label (_("Defaults"));
-  gtk_container_add (GTK_CONTAINER (button_box), button);
-
-  button = gtk_button_new_with_label (_("Save"));
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-		      GTK_SIGNAL_FUNC (save_button_cb),
-		      NULL);
-  gtk_container_add (GTK_CONTAINER (button_box), button);
+  gt_add_action_buttons (&config_buttons, button_box);
   /* 
    * Put all this gibbeirsh in the gnome app window
    */
