@@ -1,5 +1,5 @@
 /*
- * $Id: date.c,v 1.5 1998/06/14 21:18:32 gregm Exp $
+ * $Id: date.c,v 1.8 1998/09/24 16:53:39 gregm Exp $
  * GXSNMP - An snmp managment application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -20,26 +20,30 @@
  * Some generic date conversion type routines.
  */
 
-#ifndef lint
-static char const copyright[] =
-"@(#) Copyright (C) 1998 Gregory McLean";
-#endif
-static char const rcsid[] =
-"$Id: date.c,v 1.5 1998/06/14 21:18:32 gregm Exp $";
-
 #include "main.h"
 
+/*
+ * Function    : db_time_str
+ * Description : This function will convert current time into a string 
+ *               sutible for insertion into a database.
+ * Arguments   : buf    -- A pre-aloocated buffer for the result.
+ *               buflen -- The size of the buffer.
+ */ 
 char *
-db_time_str (char *buf)
+db_time_str (char *buf, int buflen)
 {
   struct tm     *tim;
   time_t        gm_time;
+  
+  g_return_val_if_fail (buf != NULL, NULL);
 
   gm_time = time (NULL);
   tim     = localtime (&gm_time);
-  strftime (buf, sizeof (buf), "%Y%m%d%H%M%S", tim);
+  strftime (buf, buflen, "%Y-%m-%d:%H:%M:%S", tim);
+  printf(buf);
   return buf;
 }
+
 /* EOF */
 
 
