@@ -1,5 +1,5 @@
 /*
- * $Id: date.h,v 1.5 1998/06/14 21:18:33 gregm Exp $
+ * $Id: date.h,v 1.6 1998/09/03 18:50:54 jochen Exp $
  * GXSNMP - An snmp managment application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -25,7 +25,7 @@
 /*
  * Return a string all ready to be stuffed into a sql database.
  */
-char          *db_time_str               (char *buf);
+char          *db_time_str               (char *buf, int bufsize);
 
 #endif
 
