@@ -1,5 +1,5 @@
 /*
- * $Id: gui.h,v 1.9 1998/08/10 23:09:43 gregm Exp $
+ * $Id: gui.h,v 1.14 1998/09/27 01:30:52 gregm Exp $
  * GXSNMP - An snmp managment application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -22,10 +22,10 @@
 #ifndef __GUI_SUP_H__
 #define __GUI_SUP_H__
 
-#include <gtk/gtk.h>
-#include <gdk/gdk.h>
+#include <config.h>
+#include <gnome.h>
+
 #include <stdarg.h>
-#include "snmp_host.h"
 
 #define RED_IDX     0
 #define GRN_IDX     1
@@ -35,6 +35,64 @@
 #define HOST_UP_COLOR 2
 #define HOST_DN_COLOR 3
 
+/*
+ * I got sick of writing the _same_ table code over and over and over
+ * so here is something to make defineing programing panels easier
+ */
+#define GT_UI_END       -1
+enum {
+  GT_ENTRY,
+  GT_COMBO,
+  GT_SPIN,
+  GT_HSLIDE,
+  GT_VSLIDE,
+  GT_RADIO
+};
+
+enum {
+  GT_BUTTON_OK,  
+  GT_BUTTON_CAN,
+  GT_BUTTON_REL,
+  GT_BUTTON_EXIT,
+  GT_BUTTON_CLOSE,
+  GT_BUTTON_SAVE,
+  GT_BUTTON_DEFAULT
+};
+
+typedef struct _GTableAttach {
+  guint     left_attach;
+  guint     right_attach;
+  guint     top_attach;
+  guint     bottom_attach;
+  guint     x_flags;
+  guint     y_flags;
+  guint     x_pad;
+  guint     y_pad;
+} GTableAttach;
+
+typedef struct _GTableDef {
+  gchar         *label_val;
+  gchar         *tooltip;
+  gchar         *entry_tag;
+  guint         entry_type;
+  gpointer      entry_data;     
+  GTableAttach  *label_attach;
+  GTableAttach  *entry_attach;
+} GTableDef;
+
+typedef struct _GTCallbacks {
+  guint         button_type;
+  gpointer      callback_func;
+  gpointer      callback_data;
+  gchar         *button_tag;
+} GTCallbacks;
+
+typedef struct _GTEntryData {
+  gboolean      editable;
+  gint          max_size;
+  gchar         *name;
+} GTEntryData;
+
 /* 
  * Handy element counting macro
  */
@@ -47,8 +105,8 @@ GtkWidget    *new_window            (char              *title,
 GtkWidget    *new_pixmap            (char            *filename,
 				     GdkWindow       *window,
 				     GdkColor        *background);
-GtkWidget    *new_host_widget       (hosts           *hentry);
-GdkColor     get_color              (int             which);
+/*GtkWidget    *new_host_widget       (hosts           *hentry); */
+GdkColor     get_color              (int             which); 
 void         destroy_pixmap_cache   (void);
 void         init_pixmap_d          (GtkWidget       *window);
 void         page_switch_cb         (GtkWidget       *widget,
@@ -59,6 +117,14 @@ void         notice_dlg             (gchar *msg, ...)
 GtkWidget    *notebook_tab          (const char      *label);
 GtkWidget    *get_widget            (GtkWidget       *widget,
 				     const gchar     *name);
+/*
+ * Some specific ui generation funcs. Probably not usefull outside of this
+ * app.
+ */
+gboolean     gt_build_ui_table      (GTableDef       *table_info,
+				     GtkWidget       *widget);
+void         gt_add_action_buttons  (GTCallbacks     *callbacks,
+				     GtkWidget       *b_box);
 #endif
 /* EOF */
 
@@ -68,3 +134,4 @@ GtkWidget    *get_widget            (GtkWidget       *widget,
 
 
 
+
