@@ -1,5 +1,5 @@
 /*
- * $Id: host.c,v 1.9 1998/08/10 23:09:44 gregm Exp $
+ * $Id: host.c,v 1.22 1998/09/29 21:42:40 gregm Exp $
  * GXSNMP -- An snmp management application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -19,21 +19,18 @@
  *
  * Host specific routines.
  */
-#ifndef lint 
-static char const copyright[] =
-"@(#) Copyright (c) 1998 Gregory McLean";
-#endif
+#include "config.h"     /* -- Autoconf groked stuff */
+#include "main.h"
 
-#include <config.h>
-#include <sys/types.h>
 #include <sys/socket.h>
-#include <netinet/in.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
 #include <netdb.h>
-#include <netinet/in.h>
-#include "main.h"
+
+#include "snmp_host.h"
+#include "net.h"
+#include "net_map.h"
 
 extern gxsnmp  *app_info;
 
@@ -76,16 +73,7 @@ check_hash_table (void)
   if (!app_info->host_hash)
       app_info->host_hash = g_hash_table_new (g_str_hash, g_str_equal);
 }
-      
-hosts *
-find_host (const char *hostname)
-{
-/*  g_return_val_if_fail (strlen (hostname) < 0, NULL); */
-  if (app_info->host_hash)	
-     return (g_hash_table_lookup (app_info->host_hash, hostname));
-  else
-     return NULL;
-}
+
 
 hosts *
 hl_add_host (hosts *entry)
@@ -94,6 +82,7 @@ hl_add_host (hosts *entry)
   char          buff[120];
   app_event     event;
   queue_entry   qentry;
+  struct hostent *hp;
 
   check_hash_table ();
   last = g_hash_table_lookup (app_info->host_hash, entry->hl_snmp.name);
@@ -103,12 +92,22 @@ hl_add_host (hosts *entry)
       DMC ();
 #endif
       last = g_new (hosts, 1);
-      memmove (last, entry, sizeof(hosts));
+      g_memmove (last, entry, sizeof(hosts));
       g_hash_table_insert (app_info->host_hash, g_strdup(last->hl_snmp.name),
 			   last);
-      last->widget     = NULL;
-      last->listwidget = NULL;
-      last->hl_if      = NULL;
+      hp = lookuphost (last->hl_snmp.name);
+      if (hp)
+	{
+	  struct in_addr bleh;
+	  memcpy (&bleh, hp->h_addr_list[0], hp->h_length);
+	  memcpy (&last->hl_addr, &bleh, sizeof (struct in_addr));
+	}
+      last->hl_map_links       = NULL;
+      last->monitor_list       = NULL;
+      last->listwidget         = NULL;
+      last->hl_if              = NULL;
+      last->hl_queue_last_time = 0;
+      last->hl_poll_interval   = 120;     /* Change to a config value */
       sprintf (buff, "Host \"%s\" has been added to the list.", 
 	       entry->hl_snmp.name);
       event.category     = GX_EVENT_INFO;
@@ -116,17 +115,19 @@ hl_add_host (hosts *entry)
       event.timestamp    = time (NULL);
       event.description  = g_strdup (buff);
       add_event (&event);
-      qentry.id = get_next_queue_id ();
+      qentry.id             = get_next_queue_id ();
       qentry.queue_callback = test_callback;
-      qentry.data = last;
+      qentry.data           = last;
       add_queue_item (&qentry);
-      update_app_stat (buff);
+      map_update_stat ("Host \"%s\" has been added to the list.", 
+		       entry->hl_snmp.name);
       return last;
     }
  
-  sprintf (buff, "Host \"%s\" was not added to the list.", entry->hl_snmp.name);
-  update_app_stat (buff);
-  return NULL;
+  sprintf (buff, "Host \"%s\" was not added to the list.", 
+	   entry->hl_snmp.name);
+  map_update_stat (buff);
+  return (hosts *)NULL;
 }
 
 void
@@ -141,16 +142,15 @@ hl_del_host (hosts *entry)
 #ifdef MEM_DEBUG
       DMC ();
 #endif
-      if (del->widget != NULL)
-	  gtk_widget_destroy (entry->widget);
       if (del->listwidget != NULL)
 	  gtk_container_remove (GTK_CONTAINER (app_info->hlist_pane->list),
 				entry->listwidget);
       if (app_info->brows_panel != NULL)
 	browser_remove_host (del->hl_snmp.name);
       g_hash_table_remove (app_info->host_hash, entry->hl_snmp.name);
-      sprintf (buff, "Host \"%s\" was deleted from the list.", entry->hl_snmp.name);
-      update_app_stat (buff);
+      sprintf (buff, "Host \"%s\" was deleted from the list.", 
+	       entry->hl_snmp.name);
+      map_update_stat (buff);
     }
 }
 
@@ -180,10 +180,7 @@ show_interface_list (hosts *entry)
 
 static int      found            = FALSE;
 static inf_list *which_interface = NULL;
-/*
- * This will search the interface list of a host
- */
-/*                hostname, hosts entry, interface to find   */
+
 static void
 search_host (void *key, void *val, void *data)
 {
@@ -212,9 +209,21 @@ search_host (void *key, void *val, void *data)
       item = g_slist_next (item);
     }
 }
-
+/*
+ * Global functions provided by this module
+ */
+/*
+ * Function    : find_interface_by_addr 
+ * Description : This function will search through all hosts and interfaces
+ *               looking for an interface by address. 
+ * Arguments   : if_addr -- struct in_addr pointer of the interface in
+ *                          in question.
+ * Returns     : inf_list structure pointer of the located interface on 
+ *               success.
+ *               NULL pointer is returned on failure.
+ */
 inf_list *
-find_interface (struct in_addr *if_addr)
+find_interface_by_addr (struct in_addr *if_addr)
 {
   found           = FALSE;
   which_interface = NULL;
@@ -225,36 +234,115 @@ find_interface (struct in_addr *if_addr)
   else
     return NULL;
 }
-
+/*
+ * Function    : add_interface
+ * Description : This function will add a new interface to a host.
+ * Arguments   : host      -- The hosts entry structure pointer for the host.
+ *               interface -- The inf_list structure pointer of the interface
+ *                            to add to this host.
+ * Returns     : None for now.
+ */
 void
 add_interface (hosts *host, inf_list *interface)
 {
   inf_list   *cp;
 
+  if (!host)
+    return;
 #ifdef MEM_DEBUG
   DMC ();
 #endif
   cp = (inf_list *)g_malloc (sizeof (inf_list));
-  memcpy ((char *)cp, interface, sizeof (inf_list));
-  cp->if_host = host;
-  find_interface (&cp->if_addr);
-  host->hl_if = g_slist_append (host->hl_if, cp);
+  if (cp)
+    {
+      memmove ((char *)cp, interface, sizeof (inf_list));
+      cp->if_host = host;
+      find_interface_by_addr (&cp->if_addr);
+      host->hl_if = g_slist_append (host->hl_if, cp);
+    }
+  else
+    {
+      return;         /* TODO: set an error code and return */
+    }
 }
 
 void 
 remove_interface (hosts *host, inf_list *interface)
 {
+  /*TODO: Write me */
 }
 
+/*
+ * Function    : get_current_host
+ * Description : This function will retrive the current host for a given
+ *               panel. Or a default if no host was set for the panel.
+ * Arguments   : widget  -- A widget of the panel in question.
+ * Returns     : The hosts entry structure pointer for the host.
+ */
 hosts *
-get_current_host ()
+get_current_host (GtkWidget *widget)
 {
-  if (app_info->current_host != NULL)
-    return (hosts *)gtk_object_get_data (GTK_OBJECT (app_info->current_host),
-					 "host_entry");
-  else
-    return NULL;
+  return NULL;
 }
 
+/*
+ * Function   : add_host_net_connection
+ * Description: This function will add a new connection from a host to 
+ *              a network. This can be the same network or multiple 
+ *              networks. This is mainly used by the mapping functions.
+ * Arguments  : host    -- The hosts structure pointer for the host.
+ *              network -- The net_entry structure pointer for the
+ *                         network to connect this host to.
+ * Returns    : None for now.
+ */
+void
+add_host_net_connection (hosts *host, net_entry *network, 
+			 GnomeCanvasItem *item)
+{
+  g_return_if_fail (network !=NULL);
+  g_return_if_fail (host != NULL);
 
+}
+
+/*
+ * Function    : find_host_by_name
+ * Description : This function will locate a host in the global list
+ *               by its name. This is mainly used in the internal list
+ *               handling stuff.
+ * Arguments   : hostname -- The name of the host to locate.
+ * Returns     : hosts entry structure pointer on success.
+ *               NULL pointer on failure.
+ */      
+hosts *
+find_host_by_name (const gchar *hostname)
+{
+
+  if (app_info->host_hash)	
+     return (g_hash_table_lookup (app_info->host_hash, hostname));
+  else
+     return NULL;
+}
+
+/*
+ * Function    : find_host_by_addr
+ * Description : This function will locate a host by an address associated
+ *               with it, on one of its interfaces, return the hosts entry
+ *               structure pointer for said host.
+ * Arguments   : addr -- The struct in_addr pointer of the address to find
+ *                       on a host.
+ * Returns     : hosts entry structure pointer on success.
+ *               NULL pointer on failure.
+ */
+hosts *
+find_host_by_addr (struct in_addr *addr)
+{
+  /*TODO: needs to be written */
+  return NULL;
+}
 /* EOF */
+
+
+
+
+
+
