@@ -1,5 +1,5 @@
 /*
- * $Id: host.h,v 1.3 1998/08/10 23:09:45 gregm Exp $
+ * $Id: host.h,v 1.6 1998/09/21 14:32:28 gregm Exp $
  * GXSNMP -- An snmp management application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -21,17 +21,6 @@
  */
 #ifndef __HOST_H__
 #define __HOST_H__
-#include "snmp_host.h"
-
-struct hostent *lookuphost 	   (char *hostname);
-hosts          *find_host          (const char *hostname);
-hosts          *hl_add_host        (hosts *entry);
-void           hl_del_host         (hosts *entry);
-hosts          *get_current_host   (void);
-void           add_interface       (hosts *entry, inf_list *interface);
-void           remove_interface    (hosts *entry, inf_list *interface);
-void           show_interface_list (hosts *entry);
-inf_list       *find_interface     (struct in_addr *if_addr);
 
 #endif
 
