@@ -1,5 +1,5 @@
 /*
- * $Id: main.h,v 1.20 1998/08/01 20:04:29 gregm Exp $
+ * $Id: main.h,v 1.26 1998/09/27 01:30:55 gregm Exp $
  * GXSNMP -- An snmp management application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -31,16 +31,13 @@
 #include <string.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-#include <sys/time.h>
 
 #include <g_snmp.h>
 #include <parse.h>
 #include <mib.h>
 
 #include "about.h"
-#include "gui.h"
 #include "menus.h"
-#include "gtksbox.h"
 #include "snmp_host.h"
 #include "snmp_lib.h"
 #include "config_panel.h"
@@ -54,7 +51,6 @@
 #include "date.h"
 #include "sql_interface.h"
 #include "queue.h"
-#include "gtkhost.h"
 #include "main_panel.h"
 #include "rmon_panel.h"
 
@@ -100,6 +96,7 @@ typedef struct __GxSnmp {
 void          update_app_stat        (gchar *msg, ...)
                                      __attribute__ ((format (printf, 1, 2)));
 gint draw_host                       (GtkWidget *widget, hosts *hentry);
+void quit_app                        ();
 #endif
 
 /* EOF */
