@@ -1,5 +1,6 @@
+
 /*
- * $Id: main_panel.c,v 1.17 1998/06/09 00:44:52 gregm Exp $
+ * $Id: main_panel.c,v 1.22 1998/09/28 17:58:20 gregm Exp $
  * GXSNMP -- An snmp mangament application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -19,25 +20,18 @@
  *
  * Main panel code. (actually the 'control panel' of sorts
  */
-#ifndef lint
-static char const copyright[] =
-"@(#) Copyright (c) 1998 Gregory McLean";
-#endif
-static char const rcsid[] =
- "$Id:";
 
 #include "main.h"
+#include "gui.h"
+#include "protos.h"
 
 /*
  * Forward declarations
  */
-static void            quit_button_cb         (GtkWidget  *widget,
-				               gpointer   data);
 static gint            panel_delete_cb        (GtkWidget  *widget,
 				               GdkEvent   *e,
 				               gpointer   data);
 static void            create_panel           (void);
-static GtkMenuFactory  *create_menu           ();
 /*
  * Menu callback functions (really just wrappers to the real functions)
  */
@@ -181,6 +175,12 @@ static GnomeUIInfo gxsnmp_menu[] = {
   { GNOME_APP_UI_ENDOFINFO }
 };
 
+static GTCallbacks button_info[] = {
+  { GT_BUTTON_CLOSE, close_cb, NULL, "close_button" },
+  { GT_BUTTON_EXIT, quit_cb, NULL, "quit_button" },
+  { GT_UI_END, NULL, NULL, NULL }
+};
+
 /* 
  * Global variables 
  */
@@ -201,9 +201,6 @@ create_panel ()
   GtkWidget        *frame;
   GtkWidget        *label;
   GtkWidget        *table;
-  GtkWidget        *button;
-  GtkMenuFactory   *mf;
-  GtkWidget        *pixmap;
   int              i;
 
   window = gnome_app_new ("GXSNMP", _("GXSNMP"));
@@ -242,18 +239,7 @@ create_panel ()
   gtk_button_box_set_spacing (GTK_BUTTON_BOX (bbox), 3);
   gtk_button_box_set_child_size (GTK_BUTTON_BOX (bbox), 85, 20);
   gtk_container_add (GTK_CONTAINER (frame), bbox);
-  button = gnome_stock_button (GNOME_STOCK_BUTTON_CLOSE);
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-		      GTK_SIGNAL_FUNC (close_cb),
-		      NULL);
-  gtk_container_add (GTK_CONTAINER (bbox), button);
-  pixmap = gnome_stock_pixmap_widget (window, GNOME_STOCK_PIXMAP_QUIT);
-  button = gnome_pixmap_button (pixmap, N_("Exit"));
-  /*  button = gtk_button_new_with_label (N_("Exit")); */
-  gtk_signal_connect (GTK_OBJECT (button), "clicked",
-		      GTK_SIGNAL_FUNC (quit_cb),
-		      NULL);
-  gtk_container_add (GTK_CONTAINER (bbox), button);
+  gt_add_action_buttons (button_info, bbox);
   /*
    * Set the gnome app specific stuff
    */
@@ -360,7 +346,7 @@ snmp_menu_monitor (GtkWidget *widget, gpointer data)
 static void
 net_add_menu_cb (GtkWidget *widget, gpointer data)
 {
-  open_add_net_panel ();
+  open_add_network_panel ();
 }
 
 static void
