@@ -1,5 +1,5 @@
 /*
- * $Id: net.h,v 1.4 1998/08/12 00:53:59 gregm Exp $
+ * $Id: net.h,v 1.12 1998/09/28 17:58:22 gregm Exp $
  * GXSNMP - An snmp managment application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -22,17 +22,12 @@
 #ifndef __NETDEF_H__
 #define __NETDEF_H__
 #include <gnome.h>
-
-typedef struct __net_entry {
-  char            *nl_name;
-  struct in_addr   nl_net;
-  struct in_addr   nl_mask;
-  int              nl_speed;
-  int              nl_flags;
-  GSList           *nl_hosts;         /* list of hosts connected */
-  GnomeCanvasGroup *nl_mgroup;        /* The canvas group for this network */
-} net_entry;
-
+#include "net_map.h"
 
 #endif
 /* EOF */
+
+
+
+
+
