@@ -22,31 +22,24 @@
 #ifndef __NET_MAP_H__
 #define __NET_MAP_H__
 #include <gnome.h>
-#include "net.h"
 
-/*
- * Functions from this module.
- */
-
-/*
- * Standard panel functions
- */
 void          open_map_panel                     (void);
 void          destroy_map_panel                  (void);
 void          hide_map_panel                     (void);
 void          reset_map_panel                    (void);
 
-/*
- * Supporting global functions
- */
-gboolean      map_add_host                       (hosts     *host,
-						  gdouble   x,
-						  gdouble   y);
-gboolean      map_del_host                       (hosts     *host);
-gboolean      map_add_network                    (net_entry *network,
-						  gint      x,
-						  gint      y);
-gboolean      map_del_network                    (net_entry *network);
-
 #endif
 /* EOF */
+
+
+
+
+
+
+
+
+
+
+
+
+
