@@ -1,5 +1,5 @@
 /*
- * $Id: snmp_host.c,v 1.24 1998/07/29 21:18:50 jochen Exp $
+ * $Id: snmp_host.c,v 1.28 1998/09/21 14:32:40 gregm Exp $
  * GXSNMP -- An snmp management application.
  * Copyright (C) 1998 Gregory McLean
  *
@@ -19,20 +19,9 @@
  *
  * Host panel code.  
  */
-#ifdef lint
-static char const copyright[] =
-"@(#) Copyright (c) 1998 Gregory McLean";
-#endif
-static char const rcsid[] =
- "$Id: snmp_host.c,v 1.24 1998/07/29 21:18:50 jochen Exp $";
-
-#include <string.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
 #include "main.h"
-
+#include "gui.h"
+#include "net_map.h"
 /* 
  * Global Variables refrenced in this module
  */
@@ -235,13 +224,12 @@ static void
 edit_ok_button_cb (GtkWidget *widget, gpointer data)
 {
   int   i;
-  char  buf[512];
   hosts *host;
 #ifdef HAVE_SQL
   sql_server    *sql_serv;
 #endif
 
-  host = get_current_host();
+  host = get_current_host(NULL);
   if (host)
     {
       for (i = 0; i < ELEMENTS(edit_labels); i++)
@@ -257,8 +245,6 @@ edit_ok_button_cb (GtkWidget *widget, gpointer data)
 	      host->hl_disp = g_strdup (gtk_entry_get_text (GTK_ENTRY
 			      (edit_panel->widget[HOST_E_DISP])));
 	      
-	      gtk_host_set_label (host->widget, gtk_entry_get_text (GTK_ENTRY
-				(edit_panel->widget[HOST_E_DISP])));
 	      break;
 	    case HOST_E_PORT:
 	      host->hl_snmp.port = atoi (gtk_entry_get_text (GTK_ENTRY 
@@ -343,7 +329,6 @@ open_edit_panel ()
       create_edit_panel ();
   else if (!GTK_WIDGET_VISIBLE (edit_panel->window))
       gtk_widget_show (edit_panel->window);
-  reset_edit_panel ();
 }
 
 void 
@@ -368,9 +353,14 @@ hide_edit_panel ()
 void
 reset_edit_panel ()
 {
-  fill_edit_panel (get_current_host());
+  fill_edit_panel (get_current_host(NULL));
 }
 
+void
+edit_panel_edit_host (hosts *host)
+{
+  fill_edit_panel (host);
+}
 /*
  * Host adding panel.
  */
@@ -410,8 +400,6 @@ create_add_host_panel ()
   GtkWidget     *bar;
   GtkWidget     *b_box;
   GtkWidget     *hbox;
-  GtkWidget     *pixmap;
-  GtkWidget     *tab_box;
   GtkAdjustment *adjustment;
   char          buf[20];
   int           i;
@@ -627,7 +615,7 @@ static void
 add_host_ok_cb (GtkWidget *widget, gpointer data)
 {
   GtkAdjustment *adjustment;
-  hosts         *hentry, *check;
+  hosts         *hentry;
   int           i;
   struct hostent *hp;
   char           *buf;
@@ -787,10 +775,6 @@ static void        create_set_panel                (void);
 static gint        set_panel_delete_cb             (GtkWidget   *widget,
 						    GdkEvent    *e,
 						    gpointer    data);
-static void        set_panel_query_button_cb       (GtkWidget   *widget,
-						    gpointer    data);
-static void        set_panel_close_button_cb       (GtkWidget   *widget,
-						    gpointer    data);
 
 /*
  * Local variables
@@ -860,17 +844,6 @@ set_panel_delete_cb (GtkWidget *widget, GdkEvent *e, gpointer data)
   return TRUE;
 }
 
-static void
-set_panel_close_button_cb (GtkWidget *widget, gpointer data)
-{
-  hide_set_panel ();
-}
-
-static void
-set_panel_query_button_cb (GtkWidget *widget, gpointer data)
-{
-}
-
 /*
  * Global panel functions (set mib panel)
  */
@@ -940,15 +913,8 @@ create_get_panel ()
   GtkWidget *frame1;
   GtkWidget *table1;
   GtkWidget *hseparator1;
-  GtkWidget *entry2;
-  GtkWidget *label3;
   GtkWidget *frame2;
   GtkWidget *hbuttonbox1;
-  GtkWidget *button1;
-  GtkWidget *button2;
-  GtkWidget *button3;
-  GtkWidget *entry1;
-  GtkWidget *combo1;
   GtkWidget *label;
 
   get_panel = (set_panel *)g_malloc (sizeof (set_panel));
@@ -1026,6 +992,7 @@ static gint
 delete_get_panel (GtkWidget *widget, GdkEvent *e, gpointer data)
 {
   destroy_get_panel ();
+  return 0;
 }
 
 static void
