@@ -1,5 +1,5 @@
 /*
- * $Id: snmp_host.h,v 1.23 1998/08/14 16:11:35 gregm Exp $
+ * $Id: snmp_host.h,v 1.32 1998/09/21 14:32:41 gregm Exp $
  * GXSNMP -- An snmp management application
  * Copyright (C) 1998 Gregory McLean
  *
@@ -27,6 +27,7 @@
 #include <gtk/gtk.h>
 #include <netdb.h>
 #include <netinet/in.h>
+#include "net_map.h"
 #include "net.h"
 
 /* 
@@ -83,62 +84,14 @@ typedef struct __edit_host {
 #define HOST_STATE_UNKNOWN   -1
 #define HOST_STATE_UP        0x01
 #define HOST_STATE_DOWN      0x02
-
+/*
+ * Some state defines (which panels need updating etc..)
+ */
+#define INFO_PANEL_OPEN          0x02
+#define INTERFACE_PANEL_OPEN     0x04
 /*
  * Simple map location cordinates.
  */
-typedef struct _map_location {
-  int           x;
-  int           y;
-  int           width;
-  int           height;
-} location;
-
-/*
- * Interface list for a given node.
- */
-typedef struct _inf_list {
-  struct in_addr    if_addr;      /* Ip address for this interface */
-  struct in_addr    if_net;       /* Network # that this interface sits on */
-  struct in_addr    if_mask;      /* The netmask for this interface */ 
-  time_t            if_lastsnmp;  /* last time we did snmp on this interface */
-  time_t            if_lastactive; /* Last time of any activity on this int */
-  time_t            if_uptime;     /* Interface uptime (snmp derived) */
-  time_t            if_lastup;     /* last update of the interface was */
-  int               if_flags;      /* Up down disabled etc.. */
-  int               if_speed;      /* Speed of this interface */
-  char              if_index;      /* Index in the mib for this interface */
-  struct _hosts     *if_host;      /* the host entry for this interface */
-} inf_list;
-
-/* 
- * The hosts structure
- */
-
-typedef struct _hosts {
-  char          *hl_disp;       /* what we should display on the map */
-  GSList        *hl_if;         /* Interface list for this host*/
-  gulong        root[SNMP_SIZE_OBJECTID];
-  int           root_length;
-  gulong        name[SNMP_SIZE_OBJECTID];
-  int           name_length;
-  u_long        hl_lastpong;    /* last response from a ping */
-  int           hl_flags;       /* Flags for this host */
-  int           hl_state;       /* The state of this host UP/Down etc.. */
-  host_snmp     hl_snmp;        /* the snmp info associated with this host */
-  GList         *monitor_list;  /* A list of mibs to monitor for this host */
-  GtkWidget     *widget;        /* the widget that displays this host */
-  GtkWidget     *listwidget;    /* the widget on the host list for this host */
-  GnomeCanvasGroup *hl_mgroup;	/* The group for this host on the map */
-  GnomeCanvasGroup *hl_ngroup;  /* The network group that this is connected to */
-  GnomeCanvasItem  *hl_mconnection; /* The connect to the network */
-  net_entry     *hl_network;    /* network we are connected to */
-  location      hl_location;    /* Where to put this host on the map */
-  u_long        hl_lastsnmpif;
-  time_t        hl_lastsnmp;
-  int           snmp_running;   /* do we have a request running? */
-  int           rowid;          /* SQL row ID */
-} hosts;
 
 #define DEFAULT_COMMUNITY	"public"           /* read */
 #define DEFAULT_WCOMMUNITY      "private"          /* write */
@@ -157,7 +110,6 @@ typedef struct _hosts {
 /*
  * Global functions defined by this module
  */
-void add_host                   (hosts *entry);
 /*
  * Exported standard panel functions
  */
@@ -188,3 +140,7 @@ void               reset_monitor_panel            (void);
 
 #endif
 /* EOF */
+
+
+
+
