@@ -1,5 +1,5 @@
 /*
- * $Id: g_message.c,v 1.9 1998/07/30 21:04:48 jochen Exp $
+ * $Id: g_message.c,v 1.12 1998/09/10 20:21:53 jochen Exp $
  * GXSNMP -- An snmp management application
  * Copyright (C) 1998 Gregory McLean & Jochen Friedrich
  *
@@ -208,9 +208,6 @@ snmpv1_prepare_response_message(guint messageProcessingModel,
                          gpointer *outgoingMessage,
                          guint *outgoingMessageLength)
 {
-  ASN1_SCK asn1;
-  guchar *eoc, *end;
-
   if (messageProcessingModel != PMODEL_SNMPV1)
     return FALSE; /* This should never happen. Something fishy going on? */
 
@@ -265,8 +262,10 @@ snmpv1_prepare_data_elements(guint transportDomain,
     return FALSE;
   g_asn1_close (&asn1, wholeMsg, &wholeMsgLength);
 
-/* FIXME */
-  *sendPduHandle = 1;
+  if (PDU->type == SNMP_PDU_RESPONSE) 
+    *sendPduHandle = -1;
+  else
+    *sendPduHandle = 0;
   return TRUE;
 }
 
@@ -308,6 +307,7 @@ snmpv2c_prepare_outgoing_message(guint transportDomain,
  * Allowing both SNMPV1 and SNMPV2C here should make this library compatible
  * with both cases.
  */
+
   if ((securityModel != SMODEL_ANY) && (securityModel != SMODEL_SNMPV1)
       && (securityModel != SMODEL_SNMPV2C))
     return FALSE;
@@ -322,11 +322,6 @@ snmpv2c_prepare_outgoing_message(guint transportDomain,
  *        type (might be different for PUT, GET(NEXT) and TRAP). Should also
  *        check for invalid PDU, however, this should as well never happen as
  *        the PDU version matches with what we expect.
- * 
- *        Depending on the meaning of PDU (struct or ANS.1 encoded), the
- *        security model might have to decode the PDU again to get to the
- *        PDU type (PUT/GET/TRAP). This seems very odd and backward to me
- *        in some way.
  */
 
 /* FIXME: another bad thing. Should do some guesses on the PDU size
@@ -442,8 +437,10 @@ snmpv2c_prepare_data_elements(guint transportDomain,
     return FALSE;
   g_asn1_close (&asn1, wholeMsg, &wholeMsgLength);
 
-/* FIXME */
-  *sendPduHandle = 1;
+  if (PDU->type == SNMP_PDU_RESPONSE) 
+    *sendPduHandle = -1;
+  else
+    *sendPduHandle = 0;
   return TRUE;
 }
 
@@ -453,6 +450,7 @@ snmpv2c_release_state( gpointer stateReference)
   return TRUE;
 }
 
+
 gboolean
 g_message_init()
 {
