@@ -1,5 +1,5 @@
 /*
- * $Id: g_security.h,v 1.3 1998/06/17 00:06:07 jochen Exp $
+ * $Id: g_security.h,v 1.4 1998/09/03 18:51:05 jochen Exp $
  * GXSNMP -- An snmp management application
  * Copyright (C) 1998 Gregory McLean & Jochen Friedrich
  *
@@ -20,7 +20,12 @@
  * Implementation of a SNMP security module as of RFC2271
  */
 
+#ifndef __G_SECURITY_H
+#define __G_SECURITY_H
+
 #include "g_snmp.h"
+#include "g_sha.h"
+#include "g_md5.h"
 
 /* Security models as in RFC2271, page 39 */
 
@@ -40,4 +45,34 @@ struct g_security
     gboolean (*generateResponseMsg) ();
   };
 
+/* Authentification types */
+#define AUTH_COMMUNITY           1
+#define AUTH_USEC                2
+
+#define AUTH_COMLEN              255
+
+/* Typedefs */
+
+typedef struct  _SNMP_AUTH       SNMP_AUTH;
+
+/* Authentication */
+
+struct _SNMP_AUTH
+{
+    guint           type;
+    guchar          name[AUTH_COMLEN];
+    guint           nlen;
+    guchar          ahash[20];
+    guint           alen;
+    guchar          phash[20];
+    guint           plen;
+};
+
+void g_password_to_key_md5(guchar *password, guint passwordlen, guchar *key);
+void g_password_to_key_sha(guchar *password, guint passwordlen, guchar *key);
+void g_localize_key_md5(guchar *key, guchar *engineID, guint enginelen);
+void g_localize_key_sha(guchar *key, guchar *engineID, guint enginelen);
+
+#endif /* __G_SECURITY_H */
+
 /* EOF */
