@@ -1,5 +1,5 @@
 /*
- * $Id: g_session.c,v 1.9 1998/07/30 21:04:49 jochen Exp $
+ * $Id: g_session.c,v 1.13 1998/09/08 21:57:09 jochen Exp $
  * GXSNMP -- An snmp management application
  * Copyright (C) 1998 Gregory McLean & Jochen Friedrich
  *
@@ -24,11 +24,14 @@ static char const copyright[] =
 "@(#) Copyright (c) 1998 Gregory McLean & Jochen Friedrich";
 #endif
 static char const rcsid[] =
-"$Id: g_session.c,v 1.9 1998/07/30 21:04:49 jochen Exp $";
+"$Id: g_session.c,v 1.13 1998/09/08 21:57:09 jochen Exp $";
 
-#include <g_snmp.h>
+#include "g_snmp.h"
+#include "mib.h"
+#include <stdio.h>
 #include <sys/socket.h>
 #include <sys/time.h>
+#include <string.h>                   /* Quite the memmove warning */
 
 extern int     errno;
 
@@ -67,7 +70,6 @@ g_async_send (host_snmp *host, guint req, GSList *objs, guint arg1, guint arg2)
 {
   snmp_request * request;
   time_t         now;
-  guint          len;
 
   now = time(NULL);
 
@@ -164,21 +166,21 @@ cb_time(host_snmp *host, void *magic)
   result = NULL;
 }
 
-static void
+static gboolean
 cb_done (host_snmp *host, void *magic, SNMP_PDU *spdu, GSList *objs)
 {
   end = 1;
   result = objs;
+  return FALSE;
 }
 
 static void
-cb_register(guint socket, void (*receiveMessage)())
+cb_register(guint r_socket, void (*receiveMessage)())
 {
-  int *socknr;
   struct inputcb *icb;
   
   icb = g_malloc(sizeof(struct inputcb));
-  icb->sock_nr = socket;
+  icb->sock_nr = r_socket;
   icb->receiveMessage = receiveMessage;
   sockets = g_slist_append(sockets, icb);
 }
@@ -271,13 +273,13 @@ gboolean
 g_pdu_add_name(GSList **pdu, guchar *name, guchar type, gpointer value)
 {
   guint  id_len;
-  gulong id[SNMP_SIZE_OBJECTID];
+  gulong pdu_id[SNMP_SIZE_OBJECTID];
   
   id_len  = SNMP_SIZE_OBJECTID;
 
-  if (!read_objid (name, id, &id_len))
+  if (!read_objid (name, pdu_id, &id_len))
     return FALSE;
-  return g_pdu_add_oid(pdu, id, id_len, type, value);
+  return g_pdu_add_oid(pdu, pdu_id, id_len, type, value);
 }
 
 gboolean
@@ -328,8 +330,6 @@ g_pdu_add_oid(GSList **pdu, gulong *myoid, guint mylength, guchar type,
 void 
 g_snmp_printf(char *buf, int buflen, struct _SNMP_OBJECT *obj)
 {
-  int timeticks, seconds, minutes, hours, days;
-
   /*
    * Changed all the sprintf's to snprintf, paranoid I know but
    * I'd rather not get caught with any buffer overflows..
@@ -337,11 +337,11 @@ g_snmp_printf(char *buf, int buflen, struct _SNMP_OBJECT *obj)
   switch(obj->type)
     {
       case SNMP_INTEGER:
-        snprintf(buf, buflen, "%d", obj->syntax.lng);
+        snprintf(buf, buflen, "%ld", obj->syntax.lng);
         break;
       case SNMP_COUNTER:
       case SNMP_GAUGE:
-        snprintf(buf, buflen, "%u", obj->syntax.ulng);
+        snprintf(buf, buflen, "%lu", obj->syntax.ulng);
         break;
       case SNMP_TIMETICKS:
 	/* replaced this duplicated code with a call to existing code */
@@ -430,7 +430,6 @@ g_snmp_timeout_cb (gpointer data)
   GSList       *mylist;
   time_t        now;
   snmp_request *request;
-  char          buf[256];
 
   now = time(NULL);
   mylist = rq_list;
@@ -478,7 +477,7 @@ g_session_response_pdu (guint messageProcessingModel,
     objs = PDU->trap.variables;
   else
     objs = PDU->request.variables;
-  if (request = g_find_request(PDU->request.id))
+  if ((request = g_find_request(PDU->request.id)))
     {
       if (memcmp(securityName->str, request->auth->str, securityName->len))
         {
@@ -488,12 +487,15 @@ g_session_response_pdu (guint messageProcessingModel,
       request->host->status = PDU->request.error_status;
       if (request->callback)
         {
-          request->callback(request->host, request->magic, PDU, objs);
+          if (request->callback(request->host, request->magic, PDU, objs))
+            g_slist_free(objs);
         }
+      else  
+        g_slist_free(objs);
       g_remove_request(request);
     }
-  g_slist_free(objs); 
+  else
+    g_slist_free(objs);
 }
 
 /* EOF */
-
