@@ -1,5 +1,5 @@
 /*
- * $Id: g_session.h,v 1.6 1998/07/27 18:41:36 jochen Exp $
+ * $Id: g_session.h,v 1.8 1998/09/08 21:57:10 jochen Exp $
  * GXSNMP -- An snmp management application
  * Copyright (C) 1998 Gregory McLean & Jochen Friedrich
  *
@@ -50,13 +50,13 @@ typedef struct _host_snmp {
   guint         port;
   guint         timeout;
   guint         version;
-  void          (*done_callback) (); /* what to call when complete */
+  gboolean      (*done_callback) (); /* what to call when complete */
   void          (*time_callback) (); /* what to call on a timeout */
   gpointer      magic;         /* can be used to pass additional data to cb */
 } host_snmp;
 
 typedef struct __snmp_request {
-  void                (*callback) ();
+  gboolean            (*callback) ();
   void                (*timeout) ();
   host_snmp           *host;
   GString             *auth;
@@ -91,6 +91,20 @@ gpointer g_async_bulk        (host_snmp *host,
                               guint nonrep, 
                               guint maxiter);
 
+GSList * g_sync_getnext      (host_snmp *host, 
+                              GSList *pdu);
+
+GSList * g_sync_get          (host_snmp *host, 
+                              GSList *pdu);
+
+GSList * g_sync_set          (host_snmp *host, 
+                              GSList *pdu);
+
+GSList * g_sync_bulk         (host_snmp *host, 
+                              GSList *pdu,
+                              guint nonrep, 
+                              guint maxiter);
+
 gboolean g_pdu_add_name      (GSList **pdu, 
                               guchar *name, 
                               guchar type, 
@@ -111,5 +125,13 @@ void g_snmp_input_cb         (gpointer    data);
 snmp_request * g_find_request (guint reqid);
 gboolean g_remove_request     (snmp_request *request);
 
+void g_session_response_pdu (guint messageProcessingModel,
+  guint securityModel, GString *securityName, guint securityLevel, 
+  GString *contextEngineID, GString *contextName, guint pduVersion,
+  SNMP_PDU *PDU);
+
+void g_snmp_printf(char *buf, int buflen, struct _SNMP_OBJECT *obj);
+
 #endif
 
+/* EOF */
