@@ -196,7 +196,7 @@ g_snmp_object_encode ( ASN1_SCK *asn1, SNMP_OBJECT *obj)
         case SNMP_OCTETSTR:
         case SNMP_OPAQUE:
             if (!g_asn1_octets_encode (asn1, &end, obj->syntax.string, 
-                                       obj->syntax.lng))
+                                       obj->syntax_len))
                 return FALSE;
             break;
         case SNMP_NULL:
@@ -339,6 +339,10 @@ g_snmp_list_encode ( ASN1_SCK *asn1, GSList *list)
 
     if (!g_asn1_eoc_encode (asn1, &eoc))
         return FALSE;
+
+/* Reverse list as we do backwards encoding here */
+
+    list = g_slist_reverse(list);
     while (list)
     {
         if (!g_snmp_object_encode (asn1, list->data))
