@@ -25,6 +25,12 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 
+/* Our Enterprise Handle */
+
+#define ENTERPRISE_GNOME 3319
+
+/* SNMP Versions */
+
 #define SNMP_V1    0
 #define SNMP_V2C   1
 #define SNMP_V2    2
@@ -39,7 +45,6 @@
 
 #define SNMP_SIZE_SMALLOBJECTID     16
 
-
 /* Requests */
 
 #define SNMP_PDU_GET                0
@@ -75,7 +80,7 @@
 #define SNMP_NOTWRITABLE           17
 #define SNMP_INCONSISTENTNAME      18
 
-/* General Traps */
+/* General SNMP V1 Traps */
 
 #define SNMP_TRAP_COLDSTART          0
 #define SNMP_TRAP_WARMSTART          1
@@ -86,7 +91,7 @@
 #define SNMP_TRAP_ENTSPECIFIC        6
 
 
-/* Types */
+/* SNMPv1 Types */
          
 #define SNMP_NULL                0
 #define SNMP_INTEGER             1    /* LngInt */
@@ -99,7 +104,7 @@
 #define SNMP_TIMETICKS           7    /* LngUns */
 #define SNMP_OPAQUE              8    /* BufChr */
 
-/* SNMPv2 Types */
+/* additional SNMPv2 Types */
 
 #define SNMP_UINTEGER            5    /* LngUns */
 #define SNMP_BITSTR              9    /* BufChr */
@@ -165,17 +170,23 @@ union _SNMP_PDU
     SNMP_REQUEST    request;
 };
 
+/* Include other SNMP headers */
+
 #include "g_asn1.h"
-#include "g_auth.h" /* Obsolete. Will disappear soon */
 #include "g_access.h"
+#include "g_date.h"
 #include "g_message.h"
 #include "g_security.h"
 #include "g_session.h"
 #include "g_transport.h"
 #include "g_dispatch.h"
 
+/* SNMP V1 trap names */
+
 extern const char *SnmpTrap[];
-                
+
+/* SNMP encoding and decoding */
+ 
 gboolean g_snmp_pdu_v1_encode ( ASN1_SCK *asn1, SNMP_PDU *pdu);
 gboolean g_snmp_pdu_v1_decode ( ASN1_SCK *asn1, SNMP_PDU *pdu);
 gboolean g_snmp_pdu_v2_encode ( ASN1_SCK *asn1, SNMP_PDU *pdu);
