@@ -1,5 +1,5 @@
 /*
- * $Id: g_transport.c,v 1.3 1998/08/06 19:14:56 jochen Exp $
+ * $Id: g_transport.c,v 1.5 1998/09/24 16:53:49 gregm Exp $
  * GXSNMP -- An snmp management application
  * Copyright (C) 1998 Gregory McLean & Jochen Friedrich
  *
@@ -24,11 +24,13 @@ static char const copyright[] =
 "@(#) Copyright (c) 1998 Gregory McLean & Jochen Friedrich";
 #endif
 static char const rcsid[] =
-"$Id: g_transport.c,v 1.3 1998/08/06 19:14:56 jochen Exp $";
-
-#include <g_snmp.h>
-#include <sys/socket.h>
+"$Id: g_transport.c,v 1.5 1998/09/24 16:53:49 gregm Exp $";
 #include "config.h"
+#include <g_snmp.h>
+#include <string.h>
+#include <stdio.h>
+#include <unistd.h>
+#include <sys/socket.h>
 
 extern int     errno;
 
@@ -235,6 +237,8 @@ ipx_get_socket()
 
 #ifdef HAVE_INET6
 
+#include <arpa/inet.h>
+
 static gint ipv6_socket  = 0;      /* file handle for SNMP traffic */
 
 static gboolean
