@@ -1,5 +1,5 @@
 /*
- * $Id: g_transport.h,v 1.1 1998/07/27 18:42:54 jochen Exp $
+ * $Id: g_transport.h,v 1.2 1998/08/18 19:58:31 jochen Exp $
  * GXSNMP -- An snmp management application
  * Copyright (C) 1998 Gregory McLean & Jochen Friedrich
  *
@@ -37,4 +37,8 @@ struct g_transport
      guint    (*getSocket) ();
   };
 
-#endif
+gboolean g_transport_init(gboolean dobind);
+
+#endif /* __G_TRANSPORT_H__ */
+
+/* EOF */
