@@ -19,17 +19,39 @@ WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 ******************************************************************/
+#include <config.h>
+
 #include <stdio.h>
 #include <ctype.h>
 #include <sys/types.h>
 #include <netinet/in.h>
+#if TIME_WITH_SYS_TIME
 #include <sys/time.h>
+#include <time.h>
+#else
+# if HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
+#endif
 
 #ifdef linux
 #include <stdlib.h>
+#endif
+
+#ifdef STDC_HEADERS
 #include <string.h>
 #endif
 
+#ifdef NEED_MEMORY_H
+#include <memory.h>
+#endif
+
+#ifndef HAVE_MEMCPY
+#define memcpy(d, s, n) bcopy ((s), (d), (n))
+#define memmove(d, s, n) bcopy ((s), (d), (n))
+#endif
 
 #include "parse.h"
 #include "mib.h"
@@ -811,18 +833,19 @@ get_symbol(gulong *objid, int objidlen, struct tree *subtree, char *buf)
     return NULL;
 
 found:
-    if (objidlen > 1){
+    if (objidlen > 1)
+      {
 	while(*buf)
-	    buf++;
+	  buf++;
 	*buf++ = '.';
 	*buf = '\0';
 	return_tree = get_symbol(objid + 1, objidlen - 1, subtree->child_list,
 				 buf);
-    } 
+      } 
     if (return_tree != NULL)
-	return return_tree;
+      return return_tree;
     else
-	return subtree;
+      return subtree;
 }
 
 
@@ -992,7 +1015,7 @@ read_objid(char *input, gulong *output, int *out_len)
   gulong *op = output;
   char buf[512];
 
-  bzero (buf, sizeof(buf));
+  memset (buf, '\0', sizeof (buf));
 
   if (*input == '.')
     input++;
@@ -1015,4 +1038,12 @@ read_objid(char *input, gulong *output, int *out_len)
   return (1);
 }
 
+struct tree *
+get_mib_tree (gulong *objid, gint objidlen)
+{
+  /*  struct tree *root = Mib; */
+
+  return (get_tree (objid, objidlen, Mib));
+}
+
 /* EOF */
