@@ -35,6 +35,11 @@ extern void print_variable   (gulong *objid,
 				int objidlen, 
 				SNMP_OBJECT *variable);
 extern char *snmp_new_prefix (char *prefix);
-
+extern void print_objid(gulong *objid, int objidlen);
+extern int  read_objid(char *input, gulong *output, int *out_len);
+extern struct tree * get_mib_tree (gulong *objid, gint objidlen);
 extern struct tree *Mib;
 #endif
+
+/* EOF */
+
