@@ -1,5 +1,5 @@
 /*
- * $Id: gtkhost.c,v 1.12 1998/08/09 16:24:24 gregm Exp $
+ * $Id: gtkhost.c,v 1.14 1998/09/04 22:34:20 gregm Exp $
  * GTKEXT - Extensions to The GIMP Toolkit
  * Copyright (C) 1998 Gregory McLean
  *
@@ -75,9 +75,10 @@ static void       gtk_host_add              (GtkContainer     *container,
 					     GtkWidget        *widget);
 static void       gtk_host_remove           (GtkContainer     *container,
 					     GtkWidget        *widget);
-static void       gtk_host_foreach          (GtkContainer     *container,
-					     GtkCallback      callback,
-					     gpointer         callback_data);
+static void       gtk_host_forall           (GtkContainer     *container,
+					     gboolean	       include_internals,
+					     GtkCallback       callback,
+					     gpointer          callback_data);
 
 static GtkContainerClass *parent_class;
 static guint host_signals[LAST_SIGNAL] = { 0 };
@@ -157,7 +158,7 @@ gtk_host_class_init (GtkHostClass *class)
 
   container_class->add             = gtk_host_add;
   container_class->remove          = gtk_host_remove;
-  container_class->foreach         = gtk_host_foreach;
+//  container_class->forall         = gtk_host_forall;
 
   class->enter = gtk_host_real_enter;
   class->leave = gtk_host_real_leave;
@@ -669,9 +670,10 @@ gtk_host_remove (GtkContainer *container,
 }
 
 static void
-gtk_host_foreach (GtkContainer *container,
-		  GtkCallback   callback,
-		  gpointer      callback_data)
+gtk_host_forall (GtkContainer *container,
+		 gboolean      include_internals,
+		 GtkCallback   callback,
+		 gpointer      callback_data)
 {
   GtkHost *host;
 
