@@ -1,5 +1,5 @@
 /*
- * $Id: gtkhost.h,v 1.7 1998/06/14 21:18:39 gregm Exp $
+ * $Id: gtkhost.h,v 1.8 1998/08/18 19:58:35 jochen Exp $
  * GTKEXT - Extensions to The GIMP Toolkit
  * Copyright (C) 1998 Gregory McLean
  *
@@ -78,6 +78,12 @@ void         gtk_host_leave          (GtkHost     *host);
 void         gtk_host_pressed        (GtkHost     *host);
 void         gtk_host_released       (GtkHost     *host);
 
+void         gtk_host_set_pixmap     (GtkWidget   *widget, 
+                                      GtkWidget   *pixmap);
+
+void         gtk_host_set_label      (GtkWidget   *host, 
+                                      const gchar *label);
+
 #ifdef __cplusplus
 }
 #endif
@@ -85,6 +91,3 @@ void         gtk_host_released       (GtkHost     *host);
 #endif
 
 /* EOF */
-
-
-
