@@ -3,8 +3,6 @@
 #include "gtkledbar.h"
 
 static int count = 0;
-static int scan  = 0;
-static int dir   = 1;
 static GtkWidget *led_bar = NULL;
 static GtkWidget *scanner = NULL;
 static GtkWidget *percent_test = NULL;
@@ -44,11 +42,7 @@ int
 main (int argc, char *argv[])
 {
   GtkWidget *window;
-  GtkAdjustment *adjustment;
-  GtkWidget *host;
-  GtkWidget *frame;
   GtkWidget *vbox;
-  GtkWidget *label;
   int       i;
   
   gtk_init (&argc, &argv);
