@@ -19,6 +19,7 @@
     ---------------------------------------------------------------------- */
 
 #include <stdio.h>
+#include <unistd.h>
 #include <gtk/gtk.h>
 #include <gnome.h>
 #include "logview.h"
@@ -134,7 +135,7 @@ void
 AboutShowWindow (GtkWidget *widget, gpointer user_data)
 {
   GtkWidget *frame, *drawing_area;
-  int w, h, x, y;
+  int w, h, x, y, i;
 
 #ifdef I_LIKE_GNOME_ABOUT
   char *author[] = {"Cesar Miquel (miquel@df.uba.ar)", NULL};
@@ -144,11 +145,11 @@ AboutShowWindow (GtkWidget *widget, gpointer user_data)
 "of the GNU General Public Licence. The log icon is a courtesy of "
 "Tuomas Kuosmanen (a.k.a tigert).";
 
+  /* go get logview.xpm in $(prefix)/share/pixmaps/logview */
   about_window = gnome_about_new ("Logview", LOGVIEW_VERSION,
-  /*about_window = gnome_about_new (NULL, 0,*/
-				  "Copyright (C) 1998",
+           			  "Copyright (C) 1998",
 				  author, comments,
-				  "logview.xpm");
+				  "logview/logview.xpm");
   gtk_widget_show (about_window);
   return;
 #endif
