@@ -184,18 +184,18 @@ make_tree_from_actions_db (GList *db)
     {
       action = (Action *)item->data;
       if (strncmp (buffer, action->tag, 49) == 0)
-	sibling = gtk_ctree_insert (ctree, sibling, NULL, text, 5, NULL, NULL,
+	sibling = gtk_ctree_insert_node (ctree, sibling, NULL, text, 5, NULL, NULL,
 				    NULL, NULL, FALSE, FALSE);
       else
 	{
 	  strncpy (buffer, action->tag, 50);
-	  sibling = gtk_ctree_insert (ctree, ctree_parent, NULL, text, 5, NULL, NULL,
+	  sibling = gtk_ctree_insert_node (ctree, ctree_parent, NULL, text, 5, NULL, NULL,
 				      NULL, NULL, FALSE, FALSE);
 	  if (ctree_parent == NULL)
 	    ctree_parent = sibling;
 	}
       /* Store data in tree */
-      gtk_ctree_set_row_data (ctree, sibling, (gpointer) action);
+      gtk_ctree_node_set_row_data (ctree, sibling, (gpointer) action);
     }
 
   /* done. */
@@ -500,7 +500,7 @@ edit_actions_entry_cb (GtkWidget *widget, gpointer data)
   if (item == NULL)
     return;
 
-  action = (Action *) gtk_ctree_get_row_data(ctree, item);
+  action = (Action *) gtk_ctree_node_get_row_data(ctree, item);
 
   edit_action_entry (action);
 
