@@ -24,6 +24,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <malloc.h>
+#include <config.h>
 #include <string.h>
 #include "logview.h"
 #include "logrtns.h"
@@ -78,7 +79,7 @@ int numlogs, curlognum;
 int log_line_sep;
 int cursor_visible;
 char *deflognames[] =
-{"/var/log/messages"};
+{PATH_MESSAGES};
 
 char *month[12] =
 {"January", "February", "March", "April", "May",
