@@ -243,18 +243,13 @@ ReadNPagesUp (Log * lg, Page * pg, int n)
    for (i = 0; i < n; i++)
    {
       ReadPageUp (lg, cp);
+      lg->firstpg = cp;
+      lg->lastpg = lg->lastpg->prev;
       if (cp->isfirstpage == TRUE)
-      {
-	 lg->firstpg = cp;
-	 lg->lastpg = cp->prev;
 	 return i+1;
-      }
       cp = cp->prev;
    }
 
-   lg->firstpg = cp->next;
-   lg->lastpg = cp;
-
    return n;
 }
 
@@ -277,18 +272,13 @@ ReadNPagesDown (Log * lg, Page * pg, int n)
    for (i = 0; i < n; i++)
    {
       ReadPageDown (lg, cp);
+      lg->lastpg = cp;
+      lg->firstpg = lg->firstpg->next;
       if (cp->islastpage == TRUE)
-      {
-	 lg->lastpg = cp;
-	 lg->firstpg = cp->prev;
 	 return i+1;
-      }
       cp = cp->next;
    }
 
-   lg->lastpg = cp->prev;
-   lg->firstpg = cp;
-
    return n;
 }
 
