@@ -64,6 +64,7 @@ int InitApp ();
 int InitPages ();
 int RepaintLogInfo (GtkWidget * widget, GdkEventExpose * event);
 int read_regexp_db (char *filename, GList **db);
+int read_actions_db (char *filename, GList **db);
 void print_db (GList *gb);
 Log *OpenLogFile (char *);
 GtkWidget *new_pixmap_from_data (char  **, GdkWindow *, GdkColor *);
@@ -101,13 +102,13 @@ GnomeUIInfo file_menu[] = {
 GnomeUIInfo view_menu[] = {
         {GNOME_APP_UI_ITEM, "Calendar                ", 
 	 "Show calendar log", CalendarMenu, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
+         GNOME_APP_PIXMAP_NONE, NULL, 'C', GDK_CONTROL_MASK, NULL},
         {GNOME_APP_UI_ITEM, "Log stats               ", 
 	 "Show log stats", LogInfo, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
+         GNOME_APP_PIXMAP_NONE, NULL, 'I', GDK_CONTROL_MASK, NULL},
         {GNOME_APP_UI_ITEM, "Zoom                    ", 
 	 "Show line info", create_zoom_view, NULL, NULL,
-         GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
+         GNOME_APP_PIXMAP_NONE, NULL, 'Z', GDK_CONTROL_MASK, NULL},
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
 
@@ -153,7 +154,7 @@ GtkWidget *app;
 GtkWidget *main_win_scrollbar;
 GtkLabel *filename_label, *date_label;
 
-GList *regexp_db, *descript_db;
+GList *regexp_db, *descript_db, *actions_db;
 ConfigData *cfg;
 int open_log_visible;
 
@@ -676,37 +677,74 @@ void
 open_databases ()
 {
   struct stat file_stat;
-  char *paths[] = {"../lib/logview", "/usr/local/lib/logview","."};
   char full_name[255];
-  int found, i, num_paths;
-
-  num_paths = 3;
+  int found, i;
 
+  /* Find regexp DB -----------------------------------------------------  */
   found = FALSE;
-  for (i=0;i<num_paths;i++)
+  if (cfg->regexp_db_path != NULL)
     {
-      sprintf (full_name, "%s/logview-regexp.db", paths[i]);
-      fprintf (stderr, "Looking for database in [%s]\n", paths[i]);
-      if (access (full_name, R_OK) == 0)
-	{
-	  found = TRUE;
-	  break;
-	}
+      sprintf (full_name, "%s/logview-regexp.db", cfg->regexp_db_path);
+      fprintf (stderr, "Looking for database in [%s]\n", cfg->regexp_db_path);
+      if (access (full_name, R_OK) == 0) 
+	found = TRUE;
     }
 
-  if (!found)
+  strncpy (full_name, LOGVIEWINSTALLPREFIX, 200);
+  strncat (full_name, "share/logview/logview-regexp.db", 40);
+  if (access (full_name, R_OK) == 0)
+     {
+         found = TRUE;
+	 cfg->regexp_db_path = g_strdup (full_name);
+         read_regexp_db (full_name, &regexp_db);
+     }
+  else
+    regexp_db = NULL;
+
+  /* Find description DB ------------------------------------------------  */
+  found = FALSE;
+  if (cfg->descript_db_path != NULL)
     {
-      ShowErrMessage ("Couldn't find description data-base.");
-      return;
+      sprintf (full_name, "%s/logview-descript.db", cfg->descript_db_path);
+      fprintf (stderr, "Looking for database in [%s]\n", cfg->descript_db_path);
+      if (access (full_name, R_OK) == 0) 
+	found = TRUE;
     }
 
-  fprintf (stderr, "Found databse in [%s]\n", paths[i]);
+  strncpy (full_name, LOGVIEWINSTALLPREFIX, 200);
+  strncat (full_name, "share/logview/logview-descript.db", 40);
+  if (access (full_name, R_OK) == 0)
+     {
+         found = TRUE;
+	 cfg->descript_db_path = g_strdup (full_name);
+         read_descript_db (full_name, &descript_db);
+     }
+  else
+    descript_db = NULL;
+
+
+  /* Find action DB ------------------------------------------------  */
+  found = FALSE;
+  if (cfg->action_db_path != NULL)
+    {
+      sprintf (full_name, "%s/logview-actions.db", cfg->action_db_path);
+      fprintf (stderr, "Looking for database in [%s]\n", cfg->action_db_path);
+      if (access (full_name, R_OK) == 0) 
+	found = TRUE;
+    }
+
+
+  strncpy (full_name, LOGVIEWINSTALLPREFIX, 200);
+  strncat (full_name, "share/logview/logview-actions.db", 40);
+  if (access (full_name, R_OK) == 0)
+     {
+         found = TRUE;
+	 cfg->action_db_path = g_strdup (full_name);
+         read_actions_db (full_name, &actions_db);
+     }
+  else
+    actions_db = NULL;
 
-  /* open database then */
-  sprintf (full_name, "%s/logview-regexp.db", paths[i]);
-  read_regexp_db (full_name, &regexp_db);
-  sprintf (full_name, "%s/logview-descript.db", paths[i]);
-  read_descript_db (full_name, &descript_db);
 
   /* If debugging then print DB */
   print_db (regexp_db);
