@@ -27,6 +27,7 @@
 #include "cancel.xpm"
 #include "remove.xpm"
 #include "add.xpm"
+#include "actions.xpm"
 
 #define MON_WINDOW_WIDTH           180
 #define MON_WINDOW_HEIGHT          150
@@ -52,6 +53,9 @@ void mon_add_log (GtkWidget *widget, GtkWidget *foo);
 void mon_read_last_page (Log *log);
 void mon_read_new_lines (Log *log);
 void mon_format_line (char *buffer, LogLine *line);
+void mon_hide_app_checkbox (GtkWidget *widget, gpointer data);
+void mon_actions_checkbox (GtkWidget *widget, gpointer data);
+void mon_edit_actions (GtkWidget *widget, gpointer data);
 gint mon_check_logs (gpointer);
 int mon_repaint (GtkWidget * widget, GdkEventExpose * event);
 
@@ -71,6 +75,7 @@ GtkWidget *srclist, *destlist;
 
 int monitorcount;
 int mon_opts_visible, mon_win_visible;
+int mon_exec_actions, mon_hide_while_monitor;
 
 /* ----------------------------------------------------------------------
    NAME:         MonitorMenu
@@ -81,7 +86,7 @@ int mon_opts_visible, mon_win_visible;
 void
 MonitorMenu (GtkWidget * widget, gpointer user_data)
 {
-   GtkWidget *hbox;
+   GtkWidget *hbox, *hbox2;
    GtkWidget *label;
    GtkWidget *scrolled_win;
    GtkWidget *list_item;
@@ -101,7 +106,8 @@ MonitorMenu (GtkWidget * widget, gpointer user_data)
 
    if (monoptions == NULL)
      {
-      monoptions = gtk_dialog_new ();
+       /* monoptions = gtk_dialog_new ();   */
+      monoptions = gtk_window_new (GTK_WINDOW_TOPLEVEL);
       gtk_container_border_width (GTK_CONTAINER (monoptions), 5);
       gtk_window_set_title (GTK_WINDOW (monoptions), "Monitor options");
       gtk_widget_set_style (monoptions, cfg->main_style);
@@ -112,7 +118,11 @@ MonitorMenu (GtkWidget * widget, gpointer user_data)
 			  GTK_SIGNAL_FUNC (close_monitor_options),
 			  NULL);
 
-      vbox = GTK_BOX (GTK_DIALOG (monoptions)->vbox);
+      vbox = (GtkBox *)gtk_vbox_new (FALSE, 2);
+      gtk_container_border_width (GTK_CONTAINER (vbox), 4);
+      gtk_container_add (GTK_CONTAINER (monoptions), GTK_WIDGET (vbox));
+      gtk_widget_show (GTK_WIDGET (vbox)); 
+
       style = gtk_style_new ();
       memcpy (style, cfg->main_style, sizeof(GtkStyle));
       style->font = cfg->heading;
@@ -173,19 +183,6 @@ MonitorMenu (GtkWidget * widget, gpointer user_data)
                           NULL);
 
 
-      /* OK button */
-      button = ButtonWithPixmap (okxpm, 62,15);
-      gtk_box_pack_start (GTK_BOX (vbox2), button, FALSE, TRUE, 0);
-      gtk_signal_connect (GTK_OBJECT (button), "clicked",
-                          GTK_SIGNAL_FUNC (go_monitor_log),
-                          srclist);
-
-      /* Cancel button */
-      button = ButtonWithPixmap (cancelxpm, 62,15);
-      gtk_box_pack_start (GTK_BOX (vbox2), button, FALSE, TRUE, 0);
-      gtk_signal_connect (GTK_OBJECT (button), "clicked",
-                          GTK_SIGNAL_FUNC (close_monitor_options),
-                          srclist);
 
       /* Destination list */
       scrolled_win = gtk_scrolled_window_new (NULL, NULL);
@@ -202,6 +199,51 @@ MonitorMenu (GtkWidget * widget, gpointer user_data)
       gtk_container_border_width (GTK_CONTAINER (scrolled_win), 3);
       gtk_widget_show (destlist);
 
+      /* Make bottom part of window  -------------------------------- */
+      hbox2 = gtk_hbox_new (FALSE, 2);
+      gtk_box_pack_start (vbox, hbox2, TRUE, TRUE, 0);
+      gtk_widget_show (hbox2);
+
+      /* Check boxes */
+      button = gtk_check_button_new_with_label ("Hide app");
+      gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), FALSE);
+      gtk_box_pack_start (GTK_BOX (hbox2), button, FALSE, TRUE, 0);
+      gtk_signal_connect (GTK_OBJECT (button), "clicked",
+                          GTK_SIGNAL_FUNC (mon_hide_app_checkbox),
+                          srclist);
+      gtk_widget_show (button);
+      
+      button = gtk_check_button_new_with_label ("Exec actions");
+      gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), TRUE);
+      gtk_box_pack_start (GTK_BOX (hbox2), button, FALSE, TRUE, 0);
+      gtk_signal_connect (GTK_OBJECT (button), "clicked",
+                          GTK_SIGNAL_FUNC (mon_actions_checkbox),
+                          srclist);
+      gtk_widget_show (button);
+
+      mon_hide_while_monitor = FALSE;
+      mon_exec_actions = TRUE;
+
+      /* Actions button */
+      button = ButtonWithPixmap (actionsxpm, 62,15);
+      gtk_box_pack_start (GTK_BOX (hbox2), button, FALSE, TRUE, 0);
+      gtk_signal_connect (GTK_OBJECT (button), "clicked",
+                          GTK_SIGNAL_FUNC (mon_edit_actions),
+                          srclist);
+
+      /* OK button */
+      button = ButtonWithPixmap (okxpm, 62,15);
+      gtk_box_pack_start (GTK_BOX (hbox2), button, FALSE, TRUE, 0);
+      gtk_signal_connect (GTK_OBJECT (button), "clicked",
+                          GTK_SIGNAL_FUNC (go_monitor_log),
+                          srclist);
+
+      /* Cancel button */
+      button = ButtonWithPixmap (cancelxpm, 62,15);
+      gtk_box_pack_start (GTK_BOX (hbox2), button, FALSE, TRUE, 0);
+      gtk_signal_connect (GTK_OBJECT (button), "clicked",
+                          GTK_SIGNAL_FUNC (close_monitor_options),
+                          srclist);
 
    }
    mon_opts_visible = TRUE;
@@ -393,6 +435,13 @@ go_monitor_log (GtkWidget * widget, gpointer client_data)
    if (i == 0)
      return;
 
+   /* Setup timer to check log */
+   gtk_timeout_add (1000, mon_check_logs, NULL);
+
+   /* If hide_while_monitor is set don't display this window */
+   if (mon_hide_while_monitor)
+     return;
+
    /* Create monitor window */
    /* setup size */
    w = 600; h = 100;
@@ -458,14 +507,11 @@ go_monitor_log (GtkWidget * widget, gpointer client_data)
 
    gtk_widget_show (monwindow);
 
-   /* Setup timer to check log */
-   gtk_timeout_add (1000, mon_check_logs, NULL);
-
 }
 
 /* ----------------------------------------------------------------------
-   NAME:	
-   DESCRIPTION:	
+   NAME:	mon_read_last_page
+   DESCRIPTION:	read last lines of the log into the monitor window.
    ---------------------------------------------------------------------- */
 
 void
@@ -505,8 +551,9 @@ mon_read_last_page (Log *log)
 }
 
 /* ----------------------------------------------------------------------
-   NAME:	
-   DESCRIPTION:	
+   NAME:	mon_read_new_lines
+   DESCRIPTION:	Read last lines in the log file and add to the monitor
+   		window.
    ---------------------------------------------------------------------- */
 
 void
@@ -548,8 +595,8 @@ mon_read_new_lines (Log *log)
 }
 
 /* ----------------------------------------------------------------------
-   NAME:	
-   DESCRIPTION:	
+   NAME:	mon_format_line
+   DESCRIPTION:	format the output for a log line.
    ---------------------------------------------------------------------- */
 
 void
@@ -563,8 +610,8 @@ mon_format_line (char *buffer, LogLine *line)
 }
 
 /* ----------------------------------------------------------------------
-   NAME:	
-   DESCRIPTION:	
+   NAME:	mon_check_logs
+   DESCRIPTION:	Routinly called to check wheter the logs have changed.
    ---------------------------------------------------------------------- */
 
 gint
@@ -579,7 +626,35 @@ mon_check_logs (gpointer data)
     if (WasModified(loglist[i]) != TRUE)
       continue;
     mon_read_new_lines (loglist[i]);
+
 fprintf(stderr, "TOUCHED!!\n");
+
     }
     return TRUE;
 }
+
+
+/* ----------------------------------------------------------------------
+   NAME:	mon_hide_app_checkbox
+   DESCRIPTION:	hide app checkbox toggled.
+   ---------------------------------------------------------------------- */
+
+void
+mon_hide_app_checkbox (GtkWidget *widget, gpointer data)
+{
+  mon_hide_while_monitor = (mon_hide_while_monitor) ? FALSE : TRUE;
+  return;
+}
+
+
+/* ----------------------------------------------------------------------
+   NAME:	mon_actions_checkbox
+   DESCRIPTION:	actions checkbox toggled.
+   ---------------------------------------------------------------------- */
+
+void
+mon_actions_checkbox (GtkWidget *widget, gpointer data)
+{
+  mon_exec_actions = (mon_exec_actions) ? FALSE : TRUE;
+  return;
+}
